Index — Prime 0.1 documentation

# Index

G | I | M | P | R | W

## G

generator (module) | get_n_prime() (in module primepackage.primemodule)

## I

is_prime() (in module primepackage.primemodule)

## M

main() (in module generator)

## P

primepackage (module) | primepackage.primeio (module) primepackage.primemodule (module)

## R

read_primes() (in module primepackage.primeio)

## W

write_primes() (in module primepackage.primeio)